==> Acme-CPANModules-GroupingElementsOfArray-0.001.tar.gz: Acme-CPANModules-GroupingElementsOfArray-0.001/lib/Acme/CPANModules/GroupingElementsOfArray.pm <==
package Acme::CPANModules::GroupingElementsOfArray;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-09-30'; # DATE
our $DIST = 'Acme-CPANModules-GroupingElementsOfArray'; # DIST
our $VERSION = '0.001'; # VERSION

our $LIST = {
    summary => 'List of modules to group elements of array into several buckets',
    entries => [
        {module=>'Array::Group'},
        {module=>'Array::GroupBy'},
        {module=>'List::GroupBy'},
        {module=>'List::Util::GroupBy'},
    ],
};

1;
# ABSTRACT: List of modules to group elements of array into several buckets

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::GroupingElementsOfArray - List of modules to group elements of array into several buckets

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::GroupingElementsOfArray (from Perl distribution Acme-CPANModules-GroupingElementsOfArray), released on 2023-09-30.

=head1 ACME::CPANMODULES ENTRIES

=over

=item L<Array::Group>

Author: L<ACCARDO|https://metacpan.org/author/ACCARDO>

=item L<Array::GroupBy>

Author: L<SAMB|https://metacpan.org/author/SAMB>

=item L<List::GroupBy>

Author: L<JLCOOPER|https://metacpan.org/author/JLCOOPER>

=item L<List::Util::GroupBy>

=back

=head1 FAQ

=head2 What is an Acme::CPANModules::* module?

An Acme::CPANModules::* module, like this module, contains just a list of module
names that share a common characteristics. It is a way to categorize modules and
document CPAN. See L<Acme::CPANModules> for more details.

=head2 What are ways to use this Acme::CPANModules module?

Aside from reading this Acme::CPANModules module's POD documentation, you can
install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
L<App::cpanm::cpanmodules> distribution):

 % cpanm-cpanmodules -n GroupingElementsOfArray

Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
distribution):

    % cpanmodules ls-entries GroupingElementsOfArray | cpanm -n

or L<Acme::CM::Get>:

    % perl -MAcme::CM::Get=GroupingElementsOfArray -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n

or directly:

    % perl -MAcme::CPANModules::GroupingElementsOfArray -E'say $_->{module} for @{ $Acme::CPANModules::GroupingElementsOfArray::LIST->{entries} }' | cpanm -n

This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
result for C<lcpan related-mods> command when it comes to finding related
modules for the modules listed in this Acme::CPANModules module.
See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
are found.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModules-GroupingElementsOfArray>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-GroupingElementsOfArray>.

=head1 SEE ALSO

Somewhat related lists pertaining to list/array:
L<Acme::CPANModules::RemovingElementsFromArray>.
L<Acme::CPANModules::PickingRandomItemsFromList>,
L<Acme::CPANModules::Import::RSAVAGE::ArrayAndSetOperations>,
L<Acme::CPANModules::Import::MJGARDNER::ListProcessing>.

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-GroupingElementsOfArray>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> Acme-CPANModules-GroupingElementsOfArray-0.002.tar.gz: Acme-CPANModules-GroupingElementsOfArray-0.002/lib/Acme/CPANModules/GroupingElementsOfArray.pm <==
package Acme::CPANModules::GroupingElementsOfArray;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-09-30'; # DATE
our $DIST = 'Acme-CPANModules-GroupingElementsOfArray'; # DIST
our $VERSION = '0.002'; # VERSION

our $LIST = {
    summary => 'List of modules to group elements of array into several buckets',
    entries => [
        {module=>'Array::Group'},
        {module=>'Array::GroupBy'},
        {module=>'List::GroupBy'},
        {module=>'List::Util::groupby'},
    ],
};

1;
# ABSTRACT: List of modules to group elements of array into several buckets

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::GroupingElementsOfArray - List of modules to group elements of array into several buckets

=head1 VERSION

This document describes version 0.002 of Acme::CPANModules::GroupingElementsOfArray (from Perl distribution Acme-CPANModules-GroupingElementsOfArray), released on 2023-09-30.

=head1 ACME::CPANMODULES ENTRIES

=over

=item L<Array::Group>

Author: L<ACCARDO|https://metacpan.org/author/ACCARDO>

=item L<Array::GroupBy>

Author: L<SAMB|https://metacpan.org/author/SAMB>

=item L<List::GroupBy>

Author: L<JLCOOPER|https://metacpan.org/author/JLCOOPER>

=item L<List::Util::groupby>

=back

=head1 FAQ

=head2 What is an Acme::CPANModules::* module?

An Acme::CPANModules::* module, like this module, contains just a list of module
names that share a common characteristics. It is a way to categorize modules and
document CPAN. See L<Acme::CPANModules> for more details.

=head2 What are ways to use this Acme::CPANModules module?

Aside from reading this Acme::CPANModules module's POD documentation, you can
install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
L<App::cpanm::cpanmodules> distribution):

 % cpanm-cpanmodules -n GroupingElementsOfArray

Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
distribution):

    % cpanmodules ls-entries GroupingElementsOfArray | cpanm -n

or L<Acme::CM::Get>:

    % perl -MAcme::CM::Get=GroupingElementsOfArray -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n

or directly:

    % perl -MAcme::CPANModules::GroupingElementsOfArray -E'say $_->{module} for @{ $Acme::CPANModules::GroupingElementsOfArray::LIST->{entries} }' | cpanm -n

This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
result for C<lcpan related-mods> command when it comes to finding related
modules for the modules listed in this Acme::CPANModules module.
See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
are found.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModules-GroupingElementsOfArray>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-GroupingElementsOfArray>.

=head1 SEE ALSO

Somewhat related lists pertaining to list/array:
L<Acme::CPANModules::RemovingElementsFromArray>.
L<Acme::CPANModules::PickingRandomItemsFromList>,
L<Acme::CPANModules::Import::RSAVAGE::ArrayAndSetOperations>,
L<Acme::CPANModules::Import::MJGARDNER::ListProcessing>.

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-GroupingElementsOfArray>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
